yakumo.neutron.v2.vpn

Package yakumo :: Package neutron :: Package v2 :: Package vpn |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.neutron.v2.vpn

     1  from . import service
     2  from . import ike_policy
     3  from . import ipsec_policy
     4  from . import ipsec_site_connection
     5
     6
     7 -class Client(object):
     8
     9 -    def __init__(self, client, **kwargs):
    10          self.service = service.Manager(client, **kwargs)
    11          self.ike_policy = ike_policy.Manager(client, **kwargs)
    12          self.ipsec_policy = ipsec_policy.Manager(client, **kwargs)
    13          self.ipsec_site_connection = ipsec_site_connection.Manager(client,
    14                                                                     **kwargs)
    15